[PATCH] D74068: [MLIR] Rename MemRefBoundCheck.cpp -> TestMemRefBoundCheck.cpp

Stephen Neuendorffer via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Wed Feb 5 11:32:49 PST 2020


This revision was automatically updated to reflect the committed changes.
Closed by commit rGb692f43e424c: [MLIR] Rename MemRefBoundCheck.cpp -> TestMemRefBoundCheck.cpp (authored by stephenneuendorffer).

Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D74068/new/

https://reviews.llvm.org/D74068

Files:
  mlir/include/mlir/Analysis/Passes.h
  mlir/test/Transforms/memref-bound-check.mlir
  mlir/test/lib/Transforms/CMakeLists.txt
  mlir/test/lib/Transforms/MemRefBoundCheck.cpp
  mlir/test/lib/Transforms/TestMemRefBoundCheck.cpp


Index: mlir/test/lib/Transforms/CMakeLists.txt
===================================================================
--- mlir/test/lib/Transforms/CMakeLists.txt
+++ mlir/test/lib/Transforms/CMakeLists.txt
@@ -10,7 +10,7 @@
   TestLoopMapping.cpp
   TestLoopParametricTiling.cpp
   TestOpaqueLoc.cpp
-  MemRefBoundCheck.cpp
+  TestMemRefBoundCheck.cpp
   TestMemRefDependenceCheck.cpp
   TestMemRefStrideCalculation.cpp
   TestParallelismDetection.cpp
Index: mlir/test/Transforms/memref-bound-check.mlir
===================================================================
--- mlir/test/Transforms/memref-bound-check.mlir
+++ mlir/test/Transforms/memref-bound-check.mlir
@@ -1,4 +1,4 @@
-// RUN: mlir-opt %s -memref-bound-check -split-input-file -verify-diagnostics | FileCheck %s
+// RUN: mlir-opt %s -test-memref-bound-check -split-input-file -verify-diagnostics | FileCheck %s
 
 // -----
 
Index: mlir/include/mlir/Analysis/Passes.h
===================================================================
--- mlir/include/mlir/Analysis/Passes.h
+++ mlir/include/mlir/Analysis/Passes.h
@@ -23,7 +23,7 @@
 template <typename T> class OpPassBase;
 
 /// Creates a pass to check memref accesses in a Function.
-std::unique_ptr<OpPassBase<FuncOp>> createMemRefBoundCheckPass();
+std::unique_ptr<OpPassBase<FuncOp>> createTestMemRefBoundCheckPass();
 
 /// Creates a pass to check memref access dependences in a Function.
 std::unique_ptr<OpPassBase<FuncOp>> createTestMemRefDependenceCheckPass();


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D74068.242710.patch
Type: text/x-patch
Size: 3152 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20200205/b27f46be/attachment.bin>


More information about the llvm-commits mailing list
Index: mlir/test/lib/Transforms/TestMemRefBoundCheck.cpp
===================================================================
--- mlir/test/lib/Transforms/TestMemRefBoundCheck.cpp
+++ mlir/test/lib/Transforms/TestMemRefBoundCheck.cpp
@@ -1,4 +1,4 @@
 //===- MemRefBoundCheck.cpp - MLIR Affine Structures Class ----------------===//
 //
 // Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 // See https://llvm.org/LICENSE.txt for license information.
@@ -29,17 +29,17 @@
 namespace {
 
 /// Checks for out of bound memef access subscripts..
-struct MemRefBoundCheck : public FunctionPass<MemRefBoundCheck> {
+struct TestMemRefBoundCheck : public FunctionPass<TestMemRefBoundCheck> {
   void runOnFunction() override;
 };
 
 } // end anonymous namespace
 
-std::unique_ptr<OpPassBase<FuncOp>> mlir::createMemRefBoundCheckPass() {
-  return std::make_unique<MemRefBoundCheck>();
+std::unique_ptr<OpPassBase<FuncOp>> mlir::createTestMemRefBoundCheckPass() {
+  return std::make_unique<TestMemRefBoundCheck>();
 }
 
-void MemRefBoundCheck::runOnFunction() {
+void TestMemRefBoundCheck::runOnFunction() {
   getFunction().walk([](Operation *opInst) {
     TypeSwitch<Operation *>(opInst).Case<AffineLoadOp, AffineStoreOp>(
         [](auto op) { boundCheckLoadOrStoreOp(op); });
@@ -48,6 +48,6 @@
   });
 }
 
-static PassRegistration<MemRefBoundCheck>
-    memRefBoundCheck("memref-bound-check",
+static PassRegistration<TestMemRefBoundCheck>
+    memRefBoundCheck("test-memref-bound-check",
                      "Check memref access bounds in a Function");
@@ -1,4 +1,4 @@
-//===- MemRefBoundCheck.cpp - MLIR Affine Structures Class ----------------===//
+//===- TestMemRefBoundCheck.cpp - Test out of bound access checks ---------===//
 //
 // Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.